pub fn try_map_error(err: &Error) -> Option<Diagnostic>Expand description
Maps selected anyhow errors to structured diagnostics with actionable fixes.
pub fn try_map_error(err: &Error) -> Option<Diagnostic>Maps selected anyhow errors to structured diagnostics with actionable fixes.