#[non_exhaustive]pub enum McpTranscriptIngestError {
SourceBytes {
limit: u64,
},
LineBytes {
limit: u64,
},
Events {
limit: usize,
},
JsonDepth {
limit: usize,
},
InvalidUtf8,
ReadFailed,
InvalidTranscript,
ConclusionIncomplete,
ConclusionInvalid,
}Expand description
A typed, value-free refusal at the MCP transcript boundary.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SourceBytes
LineBytes
Events
JsonDepth
InvalidUtf8
ReadFailed
InvalidTranscript
ConclusionIncomplete
At least one request or result needs evidence this transcript does not provide.
ConclusionInvalid
At least one request or result carries a protocol-invalid observation.