pub struct Probe {
pub name: &'static str,
pub class: &'static str,
pub input: String,
pub needle: String,
}Expand description
A corpus entry. For HOSTILE, needle is the dangerous substring that must be ABSENT from rendered
output; for BENIGN, needle is an identifying substring that must SURVIVE rendering.
Fields
name: &'static strclass: &'static strinput: Stringneedle: StringAuto Trait Implementations
impl Freeze for Probe
impl RefUnwindSafe for Probe
impl Send for Probe
impl Sync for Probe
impl Unpin for Probe
impl UnsafeUnpin for Probe
impl UnwindSafe for Probe